@@ -1,7 +1,8 @@
 from .version import __version__ # noqa
 
-from .datawidgets import (type2Widget, BoolCheckBox, IntLineEdit,
-    FloatLineEdit, StrLineEdit, TupleGroupBox, EnumComboBox)
+from .datawidgets import (type2Widget, BoolCheckBox, MISSING,
+    EmptyIntValidator, IntLineEdit, EmptyFloatValidator, FloatLineEdit,
+    StrLineEdit, TupleGroupBox, EnumComboBox)
 from .dataclass_widget import (DataclassWidget, StackedDataclassWidget,
     TabDataclassWidget,)
 
@@ -9,7 +10,10 @@ from .dataclass_widget import (DataclassWidget, StackedDataclassWidget,
 __all__ = [
     "type2Widget",
     "BoolCheckBox",
+    "MISSING",
+    "EmptyIntValidator",
     "IntLineEdit",
+    "EmptyFloatValidator",
     "FloatLineEdit",
     "StrLineEdit",
     "TupleGroupBox",
